@@ -23,7 +23,7 @@ impl Default for BATTERY_QUERY_INFORMATION {
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub struct BatteryQueryInformation(BATTERY_QUERY_INFORMATION);
 
 impl BatteryQueryInformation {
@@ -32,12 +32,6 @@ impl BatteryQueryInformation {
     }
 }
 
-impl Default for BatteryQueryInformation {
-    fn default() -> Self {
-        BatteryQueryInformation(BATTERY_QUERY_INFORMATION::default())
-    }
-}
-
 impl ops::Deref for BatteryQueryInformation {
     type Target = BATTERY_QUERY_INFORMATION;
 
